/* NitroShare - A simple network file sharing tool.
   Copyright (C) 2012 Nathan Osman

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>. */

#include <dialogs/CAcceptPromptDialog.h>
#include "ui_CAcceptPromptDialog.h"

CAcceptPromptDialog::CAcceptPromptDialog(QString name, QList<CFileHeader *> & headers)
    : ui(new Ui::CAcceptPromptDialog)
{
    ui->setupUi(this);
    setWindowFlags(Qt::WindowStaysOnTopHint);

    /* Make the first column a little bit wider. */
    ui->FileList->setColumnWidth(ui->FileList->columnAt(1), 250);

    /* Enter the files into the table, totalling up the size. */
    qint64 total_size = 0;

    foreach(CFileHeader * header, headers)
    {
        ui->FileList->insertRow(0);
        ui->FileList->setItem(0, 0, new QTableWidgetItem(header->GetFilename()));

        QTableWidgetItem * cell = new QTableWidgetItem(FormatSize(header->GetUncompressedSize()));
        cell->setTextAlignment(Qt::AlignRight | Qt::AlignVCenter);
        ui->FileList->setItem(0, 1, cell);

        total_size += header->GetUncompressedSize();
    }

    /* Set the labels according to the information supplied. */
    ui->DescriptionLabel->setText(tr("%1 would like to send you the following file(s) (%2):", "",
                                     headers.size()).arg(name).arg(total_size));
    ui->AcceptLabel->setText(tr("Do you wish to accept the file(s)?", "", headers.size()));
}

CAcceptPromptDialog::~CAcceptPromptDialog()
{
    delete ui;
}

QString CAcceptPromptDialog::FormatSize(qint64 size)
{
    if(size < 1024)
        return tr("%1 bytes").arg(size);
    else if(size < 1048576)
        return tr("%1 KB").arg((size / 102) / 10.0);
    else if(size < 1073741824)
        return tr("%1 MB").arg((size / 104858) / 10.0);
    else
        return tr("%1 GB").arg((size / 107374182) / 10.0);
}
